#
# spec file for package python-trustme
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-trustme
Version:        1.2.1
Release:        1.2
Summary:        Fake CA provider for Python tests
License:        Apache-2.0 OR MIT
URL:            https://github.com/python-trio/trustme
Source:         https://files.pythonhosted.org/packages/source/t/trustme/trustme-%{version}.tar.gz
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module idna}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyOpenSSL}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module service_identity}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cryptography >= 41.0.1
Requires:       python-idna
BuildArch:      noarch
%python_subpackages

%description
trustme is a Python package that provides a fake certificate
authority (CA) that can be used to generate "fake" TLS certs to use
in tests. The CA and certificates are fake in the sense of
https://martinfowler.com/bliki/TestDouble.html, that is, the trust
circle of the CA is limited to the test environment.

%prep
%autosetup -p1 -n trustme-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%license LICENSE.MIT
%license LICENSE.APACHE2
%doc README.rst
%{python_sitelib}/trustme
%{python_sitelib}/trustme-%{version}.dist-info

%changelog
* Thu Jan 16 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.2.1
  * Update from deprecated pyOpenSSL APIs to non-deprecated
    cryptography APIs. (#670)
* Tue Nov  5 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.2.0
  * Add support for Python 3.13. (#664)
  * Allow setting of cert's notBefore attribute (#628)
  * Add the Authority Key Identifier extension to child
    CA certificates. (#642)
  * Remove support for Python 3.8 and PyPy 3.9. (#664)
- Drop add-aki-to-child-certs.patch, merged upstream
- Drop fix2038.patch, fixed upstream
- Update BuildRequires from pyproject.toml
* Wed Aug 28 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch add-aki-to-child-certs.patch
  * Also add Authority Key Identifiers to children certs.
* Tue Mar  5 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject and autosetup macros.
* Thu Sep  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.0:
  * Allow `os.PathLike` in typing of `Blob.write_to_path`
  * Add support for PyPy 3.10 and Python 3.12
  * Remove support for Python 3.7
- drop python 2.x specific conditionals from spec file
* Sun May 14 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.0:
  * Support for ECDSA keys in certificates and use them by default.
    The type of key used for certificates can be controlled by the
    key_type parameter on the multiple methods that generate
    certificates. ECDSA certificates as they can be generated
    significantly faster.
  * Support for Python 3.10 and 3.11 (#372, 574)
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Jan 16 2023 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file
* Sat Jan 14 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Add fix2038.patch to allow tests of python-aiosmtplib to pass after 2038
* Mon Aug 30 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.9.0
  * Bump types-cryptography from 3.3.3 to 3.3.5 (#342)
  * Bump types-pyopenssl from 20.0.4 to 20.0.5 (#343)
  * Add type annotations (#341)
  * Bump charset-normalizer from 2.0.3 to 2.0.4 (#340)
  * Bump sphinx from 4.1.1 to 4.1.2
  * Bump charset-normalizer from 2.0.2 to 2.0.3
  * Bump idna from 2.10 to 3.2
  * Bump sphinx from 4.1.0 to 4.1.1
  * Bump charset-normalizer from 2.0.1 to 2.0.2
  * Bump requests from 2.25.1 to 2.26.0 (#333)
  * Bump sphinx from 4.0.2 to 4.1.0
  * Bump urllib3 from 1.26.5 to 1.26.6
  * Bump version to v0.8.0+dev
- from version 0.8.0
  * retry codecov more
  * try codecov harder
  * require codecov in ci
  * Update tests/test_trustme.py
  * close the wrapped sockets to prevent Unraisable ResourceWarnings
  * Adjust tests
  * py3.10 needs a new version of pytest
  * Set correct KU and EKU extensions
  * test on py 3.10
  * Bump pytest-cov from 2.12.0 to 2.12.1
  * Bump certifi from 2020.12.5 to 2021.5.30
  * Bump urllib3 from 1.26.4 to 1.26.5
  * Bump sphinxcontrib-htmlhelp from 1.0.3 to 2.0.0
  * Bump sphinxcontrib-serializinghtml from 1.1.4 to 1.1.5
  * Bump jinja2 from 2.11.3 to 3.0.1
  * Bump sphinx from 4.0.1 to 4.0.2
  * Bump pytest-cov from 2.11.1 to 2.12.0
  * Bump docutils from 0.16 to 0.17.1
  * Bump sphinx from 4.0.0 to 4.0.1
  * Bump service-identity from 18.1.0 to 21.1.0
  * Bump sphinx from 3.5.4 to 4.0.0
  * Bump attrs from 21.1.0 to 21.2.0
  * Bump attrs from 20.3.0 to 21.1.0
  * Bump six from 1.15.0 to 1.16.0
  * Bump pygments from 2.8.1 to 2.9.0
  * Upgrade to GitHub-native Dependabot
  * Bump babel from 2.9.0 to 2.9.1
  * Bump sphinx from 3.5.3 to 3.5.4
  * Bump docutils from 0.16 to 0.17
  * Bump sphinx from 3.5.2 to 3.5.3
  * Mention not_after in `issue_cert` signature
  * Bump urllib3 from 1.26.3 to 1.26.4
  * Bump pygments from 2.8.0 to 2.8.1
  * Bump sphinx from 3.5.1 to 3.5.2
  * Add newsfragment and Python doc for --expires-on
  * Add an option to set when the certificate should expire (--expires-on)
  * Bump coverage from 5.4 to 5.5
  * Bump sphinx from 3.5.0 to 3.5.1
  * Clarify project vision in README
  * Bump sphinx from 3.4.3 to 3.5.0
  * Bump pygments from 2.7.4 to 2.8.0
  * Bump cffi from 1.14.4 to 1.14.5
  * Bump version to 0.7.0
* Sun May  9 2021 Dirk Müller <dmueller@suse.com>
- update to 0.7.0:
  - trustme can now be used a command line interface with ``python -m
    trustme``. Get the help with ``python -m trustme --help``.
* Thu Mar 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Fri Feb  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.6.0
  * Allow specifying organization and organization unit in CA and issued certs
  * Added attr CA.from_pem to import an existing certificate authority;
    this allows migrating to trustme step-by-step.
* Tue Jun  4 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.5.2
  * support cryptography-2.7
* Fri Apr 26 2019 pgajdos@suse.com
- version update to 0.5.1
  * Update key size to 2048 bits
* Mon Mar 18 2019 Jan Engelhardt <jengelh@inai.de>
- Replace nonsense summary. Trim storytelling write style
  from description.
* Wed Feb 27 2019 Ondřej Súkup <mimi.vx@gmail.com>
- initial package
